==> websvn_2.0.orig.tar.gz: websvn-2.0/languages/korean.php <==
<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// korean-utf8.php
// Translator: Lee Jae-Hong
// Korean(utf8) language strings

// The language name is displayed in the drop down box.  It MUST be encoded as Unicode (no HTML entities).
$lang["LANGUAGENAME"] = "Korean";
$lang['LANGUAGETAG'] = 'ko';

$lang["LOG"] = "로그";
$lang["DIFF"] = "비교";

$lang["NOREP"] = "저장소가 지정되어 있지 않습니다.";
$lang["NOPATH"] = "경로를 찾을 수 없습니다.";
$lang["SUPPLYREP"] = "include/config.php 파일의 \$config->parentPath 또는 \$config->addRepository에 저장소의 경로를 지정해 주십시오.<p>설치 설명서를 참조해 주십시오.";

$lang["DIFFREVS"] = "리비전간 비교";
$lang["AND"] = "와(과)";
$lang["REV"] = "리비전";
$lang["LINE"] = "행";
$lang["SHOWENTIREFILE"] = "모두 보기";
$lang["SHOWCOMPACT"] = "바뀐 부분만 보기";

$lang["DIFFPREV"] = "이전 리비전과 비교";
$lang["BLAME"] = "수정한 사람 보기";

$lang["REVINFO"] = "리비전 정보";
$lang["GOYOUNGEST"] = "최신 리비전으로 가기";
$lang["LASTMOD"] = "마지막 변경";
$lang["LOGMSG"] = "로그 메시지";
$lang["CHANGES"] = "변경";
$lang["SHOWCHANGED"] = "변경된 파일 보기";
$lang["HIDECHANGED"] = "변경된 파일 숨기기";
$lang["NEWFILES"] = "새 파일";
$lang["CHANGEDFILES"] = "수정된 파일";
$lang["DELETEDFILES"] = "삭제된 파일";
$lang["VIEWLOG"] = "로그&nbsp;보기";
$lang["PATH"] = "경로";
$lang["AUTHOR"] = "작성자";
$lang["AGE"] = "기간";
$lang["LOG"] = "로그";
$lang["CURDIR"] = "현재 디렉토리";
$lang["TARBALL"] = "Tarball";

$lang["PREV"] = "이전";
$lang["NEXT"] = "다음";
$lang["SHOWALL"] = "모두 보기";

$lang["BADCMD"] = "명령 실행 에러";

$lang["POWERED"] = "Powered by <a href=\"http://websvn.tigris.org/\">WebSVN</a>";
$lang["PROJECTS"] = "Subversion&nbsp;프로젝트";
$lang["SERVER"] = "Subversion&nbsp;서버";

$lang["SEARCHLOG"] = "로그 검색";
$lang["CLEARLOG"] = "검색 조건 삭제";
$lang["MORERESULTS"] = "나머지 검색 결과...";
$lang["NORESULTS"] = "검색 조건에 맞는 결과가 없습니다.";
$lang["NOMORERESULTS"] = "더 이상 검색 조건에 맞는 결과가 없습니다.";

$lang["RSSFEEDTITLE"] = "WebSVN RSS feed"; 
$lang["FILESMODIFIED"] = "파일 수정됨"; 
$lang["RSSFEED"] = "RSS feed"; 

$lang["LINENO"] = "행번호";
$lang["BLAMEFOR"] = "수정한 사람 보기, 리비전 ";

$lang["YEARS"] = "년";
$lang["MONTHS"] = "개월";
$lang["WEEKS"] = "주일";
$lang["DAYS"] = "일";
$lang["HOURS"] = "시간";
$lang["MINUTES"] = "분";

$lang["GO"] = "Go";

$lang["PATHCOMPARISON"] = "경로 비교";
$lang["COMPAREPATHS"] = "경로 비교하기";
$lang["COMPAREREVS"] = "리비전 비교하기";
$lang["PROPCHANGES"] = "특성 변경 :";
$lang["CONVFROM"] = "이 비교는 바뀐 경로를 보여 줍니다.";
$lang["TO"] = "에서";
$lang["REVCOMP"] = "역 비교";
$lang["COMPPATH"] = "비교 경로:";
$lang["WITHPATH"] = "경로:";

// The following are defined by some languages to stop unwanted line splitting
// in the template files. 

$lang["NOBR"] = "";
$lang["ENDNOBR"] = "";

// $lang["NOBR"] = "<nobr>";
// $lang["ENDNOBR"] = "</nobr>";

==> websvn_2.3.0.orig.tar.gz: websvn-2.3.0/languages/korean.php <==
<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// korean.php
//
// Korean language strings (UTF-8)
// Translator: Lee Jae-Hong

$lang["LANGUAGETAG"] = "ko"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Korean";
$lang["LANGUAGENAMENATIVE"] = "한국어";
$lang["LANGUAGENAMEHTML"] = "&#54620;&#44397;&#50612;";

$lang["LOG"] = "로그";
$lang["DIFF"] = "비교";

$lang["NOREP"] = "저장소가 지정되어 있지 않습니다.";
$lang["NOPATH"] = "경로를 찾을 수 없습니다.";
// $lang["NOACCESS"] = "You do not have the necessary permissions to read this content";
// $lang["RESTRICTED"] = "Restricted access";
$lang["SUPPLYREP"] = "include/config.php 파일의 \$config->parentPath 또는 \$config->addRepository에 저장소의 경로를 지정해 주십시오.<p>설치 설명서를 참조해 주십시오.";

$lang["DIFFREVS"] = "리비전간 비교";
$lang["AND"] = "와(과)";
$lang["REV"] = "리비전";
$lang["LINE"] = "행";
$lang["LINENO"] = "행번호";
$lang["SHOWENTIREFILE"] = "모두 보기";
$lang["SHOWCOMPACT"] = "바뀐 부분만 보기";
// $lang["IGNOREWHITESPACE"] = "Ignore whitespace";
// $lang["REGARDWHITESPACE"] = "Regard whitespace";

// $lang["LISTING"] = "Directory listing";
// $lang["FILEDETAIL"] = "Details";
$lang["DIFFPREV"] = "이전 리비전과 비교";
$lang["BLAME"] = "수정한 사람 보기";
$lang["BLAMEFOR"] = "수정한 사람 보기, 리비전 ";

$lang["REVINFO"] = "리비전 정보";
$lang["GOYOUNGEST"] = "최신 리비전으로 가기";
$lang["LASTMOD"] = "마지막 변경";
$lang["LOGMSG"] = "로그 메시지";
$lang["CHANGES"] = "변경";
$lang["SHOWCHANGED"] = "변경된 파일 보기";
$lang["HIDECHANGED"] = "변경된 파일 숨기기";
$lang["NEWFILES"] = "새 파일";
$lang["CHANGEDFILES"] = "수정된 파일";
$lang["DELETEDFILES"] = "삭제된 파일";
$lang["VIEWLOG"] = "로그 보기";
$lang["PATH"] = "경로";
$lang["AUTHOR"] = "작성자";
$lang["AGE"] = "기간";
$lang["CURDIR"] = "현재 디렉토리";
$lang["TARBALL"] = "Tarball";
// $lang["DOWNLOAD"] = "Download";

$lang["PREV"] = "이전";
$lang["NEXT"] = "다음";
$lang["SHOWALL"] = "모두 보기";

$lang["BADCMD"] = "명령 실행 에러";
// $lang["UNKNOWNREVISION"] = "Revision not found";

$lang["POWERED"] = "Powered by <a href=\"http://www.websvn.info/\">WebSVN</a>";
$lang["PROJECTS"] = "Subversion 프로젝트";
$lang["SERVER"] = "Subversion 서버";

// $lang["FILTER"] = "Filtering Options";
// $lang["STARTLOG"] = "From rev";
// $lang["ENDLOG"] = "To rev";
// $lang["MAXLOG"] = "Max revs";
$lang["SEARCHLOG"] = "로그 검색";
$lang["CLEARLOG"] = "검색 조건 삭제";
$lang["MORERESULTS"] = "나머지 검색 결과...";
$lang["NORESULTS"] = "검색 조건에 맞는 결과가 없습니다.";
$lang["NOMORERESULTS"] = "더 이상 검색 조건에 맞는 결과가 없습니다.";
// $lang["NOPREVREV"] = "No previous revision";

$lang["RSSFEEDTITLE"] = "WebSVN RSS feed";
$lang["FILESMODIFIED"] = "파일 수정됨";
$lang["RSSFEED"] = "RSS feed";

$lang["DAYLETTER"] = "일";
$lang["HOURLETTER"] = "시간";
$lang["MINUTELETTER"] = "분";
$lang["SECONDLETTER"] = "초";

$lang["GO"] = "Go";

$lang["PATHCOMPARISON"] = "경로 비교";
$lang["COMPAREPATHS"] = "경로 비교하기";
$lang["COMPAREREVS"] = "리비전 비교하기";
$lang["PROPCHANGES"] = "특성 변경 :";
$lang["CONVFROM"] = "이 비교는 바뀐 경로를 보여 줍니다.";
$lang["TO"] = "에서";
$lang["REVCOMP"] = "역 비교";
$lang["COMPPATH"] = "비교 경로:";
$lang["WITHPATH"] = "경로:";
// $lang["FILEDELETED"] = "File deleted";
// $lang["FILEADDED"] = "New file";

// The following are defined by some languages to stop unwanted line splitting
// in the template files.

$lang["NOBR"] = "";
$lang["ENDNOBR"] = "";
